EasyExtend.langlets.p4d.langlet

Package EasyExtend :: Package langlets :: Package p4d :: Module langlet |
[hide private]
[frames] | no frames]

# Module langlet

Classes | [hide private]
| SpecialElement
| LangletImporter Defines langlet specific import behaviour.
| LangletTokenizer Defines langlet specific token stream processor.
| LangletTransformer Defines langlet specific CST transformations.
| InteractiveTransformer

Variables | [hide private]
| __publish__ = ``[``'``mapeval``'``,` `'``P4DNode``'``,` `'``P4D``'``,` `'``P4DList``'``,` `'``P4DNam``...``

Variables Details | [hide private]

  ### __publish__ Value:
      ['mapeval',
       'P4DNode',
       'P4D',
       'P4DList',
       'P4DName',
       'P4DNamespace',
       'P4DAccessError',
       'P4DContentList',
      ...